featureflags.api.default package
================================

Submodules
----------

featureflags.api.default.authenticate module
--------------------------------------------

.. automodule:: featureflags.api.default.authenticate
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.default.get\_all\_segments module
--------------------------------------------------

.. automodule:: featureflags.api.default.get_all_segments
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.default.get\_feature\_config module
----------------------------------------------------

.. automodule:: featureflags.api.default.get_feature_config
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.default.get\_feature\_config\_by\_identifier module
--------------------------------------------------------------------

.. automodule:: featureflags.api.default.get_feature_config_by_identifier
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.default.get\_segment\_by\_identifier module
------------------------------------------------------------

.. automodule:: featureflags.api.default.get_segment_by_identifier
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.default.post\_metrics module
---------------------------------------------

.. automodule:: featureflags.api.default.post_metrics
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.api.default.stream module
--------------------------------------

.. automodule:: featureflags.api.default.stream
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: featureflags.api.default
   :members:
   :undoc-members:
   :show-inheritance:
